# Connect to Microsoft Graph
Connect-MgGraph -Scopes "DeviceManagementConfiguration.ReadWrite.All" -NoWelcome

# Get Tenant ID
$tenant = Get-MgOrganization
$tenantId = $tenant.Id

$policies = Get-ChildItem ./policies 

ForEach ($policie in $policies) {
    $PolicieName = $policie.name
    
    $JsonData = Get-Content -Path ./policies/$PolicieName -Raw
    $JsonDataUpdated = $JsonData -replace '\$tenantId', $tenantId
    $PolicyObject = $JsonDataUpdated  | ConvertFrom-Json

    try {
        $uri = "https://graph.microsoft.com/beta/deviceManagement/configurationPolicies"  # Using the beta version
        $response = Invoke-MgGraphRequest -Method POST -Uri $uri -Body ($PolicyObject | ConvertTo-Json -Depth 10)
        Write-Host "✅ $PolicieName - successfully imported!"
        #$response
    } catch {
        Write-Error "❌ An error occurred while importing the policy: $_"
    }
}


$null = Disconnect-Graph -ErrorAction SilentlyContinue
